sqltriples.Types.Expression

Package sqltriples :: Module Types :: Class Expression |
[show private | hide private]
[frames | no frames]

## Class Expression

    AbstractExpression --+
                         |
                        Expression

Known Subclasses:
  `LiteralExpression`, `URIRefExpression`

    An general class wrapping an expression and associated values.

Method Summary
| ``__init__`(self, expr, values, value_type)` Initialise the expression with the 'expr' string and a sequence of 'values', optionally indicating the expression's 'value_type' ('L' for Literal, 'U' for URIRef).
| `get_expression(self)`
Inherited from AbstractExpression
| ``__getitem__`(self, i)`
| ``__len__`(self)`

Method Details

### __init__(self, expr, values, value_type='L') (Constructor)
    Initialise the expression with the 'expr' string and a sequence of
    'values', optionally indicating the expression's 'value_type' ('L' for
    Literal, 'U' for URIRef).

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net